@@ -320,6 +320,7 @@ gdict_strategy_chooser_constructor (GType                  type,
   gtk_widget_push_composite_child ();
 
   sw = gtk_scrolled_window_new (NULL, NULL);
+  gtk_widget_set_hexpand(sw, TRUE);
   gtk_widget_set_composite_name (sw, "gdict-strategy-chooser-scrolled-window");
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 		  		  GTK_POLICY_AUTOMATIC,
@@ -346,7 +347,7 @@ gdict_strategy_chooser_constructor (GType                  type,
   gtk_container_add (GTK_CONTAINER (sw), priv->treeview);
   gtk_widget_show (priv->treeview);
 
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
   priv->refresh_button = gtk_button_new ();
   gtk_button_set_image (GTK_BUTTON (priv->refresh_button),
